using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Diagnostics;
using System.IO;

/// <summary>
/// Summary description for DeploymentTrackingModule
/// </summary>
public class DeploymentTrackingModule : IHttpModule
{
   #region IHttpModule Members

   public void Dispose()
   {
   }

   public void Init(HttpApplication app)
   {
      app.AuthorizeRequest += OnAuthorizeRequest;
   }

   #endregion

   private void OnAuthorizeRequest(object sender, EventArgs e)
   {
      // Gather context information
      HttpRequest request = HttpContext.Current.Request;
      string user = request.LogonUserIdentity.Name;
      string resource = request.Url.ToString();
      string localPath = request.Url.LocalPath;
      string resourcePath = 
         HttpContext.Current.Server.MapPath(localPath);
      string fileExtension = Path.GetExtension(resource);
      // Log deployment manifest requests
      if (fileExtension == ".application")
      {
         // Get version
         string version = 
            ManifestHelper.GetManifestVersion(resourcePath);
         // Log potential deployment / update check
         Debug.WriteLine(
            string.Format(
               "Deployment manifest request: {0}\n" +
               "User: {1}\nVersion: {2}\n",
               resource, user, version));
      }
      // Log application manifest requests
      if (fileExtension == ".manifest")
      {
         // Get version
         string version = 
            ManifestHelper.GetManifestVersion(resourcePath);
         // Log deployment/update in progresss
         Debug.WriteLine(
            string.Format(
               "Application deployment or update in progress:\n" +
               "Manifest: {0}\nUser: {1}\nVersion: {2}\n",
               resource, user, version));
      }
      if (fileExtension == ".deploy")
      {
         // Log app file retrieval
         Debug.WriteLine(
            string.Format(
               "Application file download: {0}\nUser: {1}",
               resource, user));
      }
   }
}
